==> midone-1.0.1.tar.gz: midone-1.0.1/README.md <==
# MidOne ![tests](https://github.com/microprediction/endersgame/actions/workflows/tests.yml/badge.svg)

Utilities to help build `Attackers` that detect small departures from martingality in time-series. 

### [Crunch Mid-One Contest](https://www.crunchdao.com/) notebooks

Play the game! You might win some cash or even have ongoing upside. 

| Contest notebook | Description |
| --- | --- |
| [Mean reversion attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/mean_reversion_attacker/mean_reversion_attacker.ipynb) | Illustrates use of the `Attacker` class|
| [Momentum attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/momentum_attacker/momentum_attacker.ipynb) | Illustrates use of running calculations |
| [Regression Attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/regression_attacker/regression_attacker.ipynb) | Illustrates running regression pattern |


### About
This package is intended to make life simpler for those participating in an ongoing tournament at [CrunchDAO.com](https://www.crunchdao.com), although it hopefully has independent interest. For instance, you might build on `Attacker` or examples herein to help find signal in your model residuals.  

 - Standalone colab [notebooks](https://github.com/microprediction/endersnotebooks) demonstrating `Attacker` class independently of the contest. 
 - See the README in [attacker.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/attacker.md).  
 - It's also highly recommended to read the [FAQ.md](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/FAQ.md).


### Install 
Stable:

     pip install endersgame 

Latest:

     pip install git+https://github.com/microprediction/endersgame.git
 
### Getting help

See the  [discord channel](https://discord.gg/NuqJTcYQ2J) and [CrunchDAO.com](https://www.crunchdao.com).

==> midone-1.0.4.tar.gz: midone-1.0.4/README.md <==
# Mid+One ![tests](https://github.com/microprediction/midone/actions/workflows/tests.yml/badge.svg)

Utilities to help build `Attackers` that detect small departures from martingality in time-series. 

### Contest entry notebook examples

Play the game at [CrunchDAO.com](https://www.crunchdao.com/)! You might win some cash or even have ongoing upside. 

| Contest notebook | Description |
| --- | --- |
| [Mean reversion attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/mean_reversion_attacker/mean_reversion_attacker.ipynb) | Illustrates use of the `Attacker` class|
| [Momentum attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/momentum_attacker/momentum_attacker.ipynb) | Illustrates use of running calculations |
| [Regression Attacker](https://github.com/crunchdao/quickstarters/blob/master/competitions/mid-one/regression_attacker/regression_attacker.ipynb) | Illustrates running regression pattern |


### About
This package is intended to make life simpler for those participating in an ongoing tournament at [CrunchDAO.com](https://www.crunchdao.com), although it hopefully has independent interest. For instance, you might build on `Attacker` or examples herein to help find signal in your model residuals.  

 - See the README in [attacker.md](https://github.com/microprediction/midone/blob/main/midone/attackers/attacker.md).  
 - It's also highly recommended to read the [FAQ.md](https://github.com/microprediction/midone/blob/main/midone/attackers/FAQ.md).


### Install 
Stable:

     pip install midone 

Latest:

     pip install git+https://github.com/microprediction/midone.git
 
### Getting help

See the  [discord channel](https://discord.gg/NuqJTcYQ2J) and [CrunchDAO.com](https://www.crunchdao.com).
